#
# util.mk look for ALTQ-SRC (if asked for) and set some flags
#

# look for ALTQ-SRC (if asked for) and set some flags
.if defined(WITH_ALTQ) && (${WITH_ALTQ} == "yes")
.for _dir in ${ALTQ_SRC} /usr/src/sys.altq /sys /usr/src/sys
.if !defined(SYSDIR) && exists(${_dir}/altq/altq.h)
SYSDIR= ${_dir}
.endif
.endfor
.if defined(SYSDIR)
ALTQ_SUPPORT = yes
.else
.error No ALTQ kernel source found! Hint location with ALTQ_SRC\
e.g. make WITH_ALTQ=yes ALTQ_SRC=/usr/altq.src
.endif
.endif

BASE?= /usr/local/pfsys/openbsd

CFLAGS+= -I${.CURDIR}/../include/support

.PATH: ${.CURDIR}/../include/support

update_cp:
.for file in ${SRCS}
.if defined(LOC_BASE) && !empty(LOC_BASE)
	@if [ -e ${LOC_BASE}/${file} ]; then				\
		cp ${LOC_BASE}/${file} ${.CURDIR}/${file};		\
		echo "+ ${LOC_BASE}/${file}";				\
	 else								\
		echo "! ${LOC_BASE}/${file}";				\
	 fi
.else
	@if [ -e ${BASE}/${file} ]; then				\
		cp ${BASE}/${file} ${.CURDIR}/${file};			\
		echo "+ ${BASE}/${file}";				\
	 else								\
		echo "! ${BASE}/${file}";				\
	 fi
.endif
.endfor
.for file in ${UPADD}
	@if [ ! "`dirname ${file}`"=="." ]; then		\
		if [ -e ${file} ]; then				\
			cp ${file} ${.CURDIR};			\
			echo "+ ${file}";			\
		fi;						\
	 else							\
		if [ -e ${BASE}/${file} ]; then			\
			cp ${BASE}/${file} ${.CURDIR};		\
			echo "+ ${BASE}/${file}";		\
		elif [ -e ${LOC_BASE}/${file} ]; then		\
			cp ${LOC_BASE}/${file} ${.CURDIR};	\
			echo "+ ${LOC_BASE}/${file}";		\
		else						\
			echo "! ${file}";			\
		fi						\
	 fi
.endfor
.for file in ${NEWADD}
	@if [ ! -e ${file} ]; then		\
		echo "! ${file} missing!";	\
	 fi
.endfor

update_diff:
.for file in ${SRCS}
.if defined(LOC_BASE) && !empty(LOC_BASE)
	@-if [ -e ${LOC_BASE}/${file} ]; then				\
		diff -u ${.CURDIR}/${file} ${LOC_BASE}/${file} >	\
		    ${.CURDIR}/${file}.patch ;				\
	 else								\
		echo "! ${LOC_BASE}/${file}";				\
	 fi
.else
	@-if [ -e ${BASE}/${file} ]; then			\
		diff -u ${.CURDIR}/${file} ${BASE}/${file} > 	\
		    ${.CURDIR}/${file}.patch ;			\
	 else							\
		echo "! ${BASE}/${file}";			\
	 fi
.endif
	@-if [ ! -s ${.CURDIR}/${file}.patch ]; then	\
		rm ${.CURDIR}/${file}.patch;		\
		echo "- ${.CURDIR}/${file}.patch";	\
	 else						\
		echo "+ ${file}";			\
	 fi
.endfor
.for file in ${UPADD}
	@-if [ ! "`dirname ${file}`"=="." ]; then			\
		if [ -e ${file} ]; then					\
			diff -u ${.CURDIR}/`basename ${file}` ${file} >	\
			    ${.CURDIR}/`basename ${file}`.patch;	\
		fi;							\
	 else								\
		if [ -e ${BASE}/${file} ]; then				\
			diff -u ${.CURDIR}/`basename ${file}` 		\
			    ${BASE}/${file} >				\
			    ${.CURDIR}/`basename ${file}`.patch;	\
		elif [ -e ${LOC_BASE}/${file} ]; then			\
			diff -u ${.CURDIR}/`basename ${file}` 		\
			    ${LOC_BASE}/${file} >			\
			    ${.CURDIR}/`basename ${file}`.patch;	\
		else							\
			echo "! ${file}";				\
		fi							\
	 fi

	@if [ ! -s ${.CURDIR}/`basename ${file}`.patch ]; then	\
		rm ${.CURDIR}/`basename ${file}`.patch;		\
		echo "- ${.CURDIR}/`basename ${file}`.patch";	\
	 else							\
		echo "+ `basename ${file}`";			\
	 fi
.endfor
.for file in ${NEWADD}
	@if [ ! -e ${file} ]; then		\
		echo "! ${file} missing!";	\
	 fi
.endfor
